@@ -1,11 +1,11 @@
 GeomVline <- proto(Geom, {
-  new <- function(., data = NULL, mapping = NULL, xintercept = 0, ...) {
-    if (!missing(xintercept) && is.numeric(xintercept)) {
-      df <- data.frame(xintercept = xintercept)
-      .super$new(., aes(xintercept = xintercept), data = df, ignore.extra = TRUE, ...)
-    } else {
-      .super$new(., data = data, mapping = mapping, ignore.extra = TRUE, xintercept = xintercept, ...)
+  new <- function(., data = NULL, mapping = NULL, xintercept = NULL, ...) {
+    if (is.numeric(xintercept)) {
+      data <- data.frame(xintercept = xintercept)
+      mapping <- aes_all(names(data))
     }
+    .super$new(., data = data, mapping = mapping, inherit.aes = FALSE, 
+      xintercept = xintercept, ...)
   }
   
   draw <- function(., data, scales, coordinates, ...) {
@@ -21,7 +21,7 @@ GeomVline <- proto(Geom, {
   details <- "<p>This geom allows you to annotate the plot with vertical lines (see geom_hline and geom_abline for other types of lines)</p>\n\n<p>There are two ways to use it.  You can either specify the intercept of the line in the call to the geom, in which case the line will be in the same position in every panel.  Alternatively, you can supply a different intercept for each panel using a data.frame.  See the examples for the differences</p>"
   
   default_stat <- function(.) StatVline
-  default_aes <- function(.) aes(colour="black", size=0.5, linetype=1)
+  default_aes <- function(.) aes(colour="black", size=0.5, linetype=1, alpha = 1)
   guide_geom <- function(.) "vline"
 
   draw_legend <- function(., data, ...) {
@@ -29,7 +29,7 @@ GeomVline <- proto(Geom, {
 
     with(data, 
       ggname(.$my_name(), segmentsGrob(0.5, 0, 0.5, 1, default.units="npc",
-      gp=gpar(col=colour, lwd=size * .pt, lty=linetype, lineend="butt")))
+      gp=gpar(col=alpha(colour, alpha), lwd=size * .pt, lty=linetype, lineend="butt")))
     )
   }
 
@@ -45,14 +45,11 @@ GeomVline <- proto(Geom, {
     p + geom_vline(xintercept = 5)
     p + geom_vline(xintercept = 1:5)
     p + geom_vline(xintercept = 1:5, colour="green")
-    p + geom_vline(xintercept = "mean", size=2, colour = alpha("red", 0.2))
     
     last_plot() + coord_equal()
     last_plot() + coord_flip()
     
-    # Lines from data
-    p <- ggplot(mtcars, aes(x = wt, y = mpg)) + geom_point()
-    p + geom_vline(xintercept = "mean") + facet_grid(. ~ cyl)
-    p + geom_vline(aes(colour = factor(cyl)), xintercept = "mean")
+    p2 <- p + aes(colour = factor(cyl))
+    p2 + geom_vline(xintercept = 15)
   }  
 })
