@@ -29,7 +29,6 @@ theme_gray <- function(base_size = 12) {
     panel.margin =      unit(0.25, "lines"),
 
     strip.background =  theme_rect(fill = "grey80", colour = NA), 
-    strip.label =       function(variable, value) value, 
     strip.text.x =      theme_text(size = base_size * 0.8),
     strip.text.y =      theme_text(size = base_size * 0.8, angle = -90),
 
@@ -52,7 +51,7 @@ theme_bw <- function(base_size = 12) {
     axis.text.y =       theme_text(size = base_size * 0.8, lineheight = 0.9, hjust = 1),
     axis.ticks =        theme_segment(colour = "black", size = 0.2),
     axis.title.x =      theme_text(size = base_size, vjust = 1),
-    axis.title.y =      theme_text(size = base_size, angle = 90, vjust = 0),
+    axis.title.y =      theme_text(size = base_size, angle = 90, vjust = 0.5),
     axis.ticks.length = unit(0.3, "lines"),
     axis.ticks.margin = unit(0.5, "lines"),
 
@@ -70,7 +69,6 @@ theme_bw <- function(base_size = 12) {
     panel.margin =      unit(0.25, "lines"),
 
     strip.background =  theme_rect(fill = "grey80", colour = "grey50"), 
-    strip.label =       function(variable, value) value, 
     strip.text.x =      theme_text(size = base_size * 0.8),
     strip.text.y =      theme_text(size = base_size * 0.8, angle = -90),
 
