@@ -5,7 +5,10 @@
 # @arguments multiplicative constract
 # @arguments additive constant
 # @keyword manip 
-expand_range <- function(range, mul=0, add=0) {
-  if (diff(range) == 0) return(c(range[1] - 0.5, range[1] + 0.5))
-  range + c(-1, 1) * (diff(range) * mul + add)
+expand_range <- function(range, mul = 0, add = 0, zero = 0.5) {
+  if (length(range) == 1 || diff(range) == 0) {
+    c(range[1] - zero, range[1] + zero)
+  } else {    
+    range + c(-1, 1) * (diff(range) * mul + add)
+  }
 }
\ No newline at end of file
