@@ -90,6 +90,7 @@ scale_x_pow <- ScalePow$build_accessor(list(variable = "\"x\""))
 scale_x_pow10 <- ScalePow10$build_accessor(list(variable = "\"x\""))
 scale_x_prob <- ScaleProb$build_accessor(list(variable = "\"x\""))
 scale_x_probit <- ScaleProbit$build_accessor(list(variable = "\"x\""))
+scale_x_recip <- ScaleRecip$build_accessor(list(variable = "\"x\""))
 scale_x_reverse <- ScaleReverse$build_accessor(list(variable = "\"x\""))
 scale_x_sqrt <- ScaleSqrt$build_accessor(list(variable = "\"x\""))
 scale_y_asn <- ScaleAsn$build_accessor(list(variable = "\"y\""))
@@ -108,6 +109,7 @@ scale_y_pow <- ScalePow$build_accessor(list(variable = "\"y\""))
 scale_y_pow10 <- ScalePow10$build_accessor(list(variable = "\"y\""))
 scale_y_prob <- ScaleProb$build_accessor(list(variable = "\"y\""))
 scale_y_probit <- ScaleProbit$build_accessor(list(variable = "\"y\""))
+scale_y_recip <- ScaleRecip$build_accessor(list(variable = "\"y\""))
 scale_y_reverse <- ScaleReverse$build_accessor(list(variable = "\"y\""))
 scale_y_sqrt <- ScaleSqrt$build_accessor(list(variable = "\"y\""))
 scale_z_discrete <- ScaleDiscretePosition$build_accessor(list(variable = "\"z\""))
